##  Executing Transformations
Executing the Transformation makes all implied impacts a reality. This implies that the impacts are now realized in your active as-is architecture.
To execute a Transformation item, follow the below instructions:
  1. Navigate to the Transformation tab in the Fact Sheet.
  2. Hover over the name of the Transformation you want to execute, and you will see the Execute button appear in the right corner.
  3. Click Execute to execute the Transformation.
